import * as React from 'react';
import {Box, ButtonGroup} from "@material-ui/core";
import {GrantedButton} from "../component_permissions/GrantedButton";
import {t, Trans} from "@lingui/macro";
import {DeniedButton} from "../component_permissions/DeniedButton";
import {useModelContext} from '@rx-suite/ui';
import {RoleModel} from "../../stores/RoleStore";

export const RolesGrantAllButtons = () => {
    const model = useModelContext() as RoleModel;

    const setAll = React.useCallback(v => {
        model.enabledPermissions.forEach(({rolePermission}) => {
            rolePermission.viewModel.permitted = v;
        })
    }, [model.enabledPermissions]);

    const grantAll = React.useCallback(() => {
        const result = window.confirm(t`This will grant all permissions across all modules. Continue?`);
        if (result) {
            setAll(true);
        }

    }, [setAll]);

    const revokeAll = React.useCallback(() => {
        const result = window.confirm(t`This will revoke all permissions across all modules. Continue?`);
        if (result) {
            setAll(false);
        }
    }, [setAll]);

    return (
        <Box p={2}>
            <ButtonGroup color="primary">
                <GrantedButton onClick={grantAll}>
                    <Trans>Grant All</Trans>
                </GrantedButton>
                <DeniedButton onClick={revokeAll}>
                    <Trans>Revoke All</Trans>
                </DeniedButton>
            </ButtonGroup>
        </Box>
    )
}