import * as React from "react";
import {observer} from "mobx-react-lite";
import {CheckboxField} from "@rx-suite/ui";
import {t, Trans} from "@lingui/macro";
import {Schedule, ScheduleRecurrenceWeekday, ShiftModel} from "../../../stores/ShiftStore";
import {FormControl, FormGroup, FormLabel} from "@material-ui/core";
import {runInAction} from "mobx";
import {isArrayLike} from "@rx-suite/data";

export const WeeklyOptions: React.FunctionComponent<{ shift: ShiftModel, schedule: Schedule, scheduleIndex: number }> = observer(({
                                                                                                                                      shift,
                                                                                                                                      schedule,
                                                                                                                                      scheduleIndex
                                                                                                                                  }) => {
    const on = React.useMemo(() => {
        return isArrayLike(schedule.recurrence_rule.on) ? schedule.recurrence_rule.on as ScheduleRecurrenceWeekday[] : [];
    }, [schedule.recurrence_rule.on]);

    const handleDaysChange = React.useCallback((e) => {
        const day: ScheduleRecurrenceWeekday = e.target.value;
        if (e.target.checked) {
            runInAction(() => {
                shift.viewModel.shift_schedules = [...shift.viewModel.shift_schedules.slice(0, scheduleIndex),
                    {
                        ...shift.viewModel.shift_schedules[scheduleIndex],
                        recurrence_rule: {
                            ...shift.viewModel.shift_schedules[scheduleIndex].recurrence_rule,
                            on: [...on, day]
                        }
                    },
                    ...shift.viewModel.shift_schedules.slice(scheduleIndex + 1)];
            });
        } else {
            runInAction(() => {
                shift.viewModel.shift_schedules = [...shift.viewModel.shift_schedules.slice(0, scheduleIndex),
                    {
                        ...shift.viewModel.shift_schedules[scheduleIndex],
                        recurrence_rule: {
                            ...shift.viewModel.shift_schedules[scheduleIndex].recurrence_rule,
                            on: on.filter(d => d !== day)
                        }
                    },
                    ...shift.viewModel.shift_schedules.slice(scheduleIndex + 1)];
            });
        }
    }, [shift.viewModel, scheduleIndex, on]);
    return (
        <FormControl component={"fieldset"} onChange={handleDaysChange}>
            <FormLabel component={"legend"}><Trans>On</Trans></FormLabel>
            <FormGroup row>
                <CheckboxField label={t`Sunday`} value={'sunday'} checked={on.includes('sunday')}/>
                <CheckboxField label={t`Monday`} value={'monday'} checked={on.includes('monday')}/>
                <CheckboxField label={t`Tuesday`} value={'tuesday'} checked={on.includes('tuesday')}/>
                <CheckboxField label={t`Wednesday`} value={'wednesday'} checked={on.includes('wednesday')}/>
                <CheckboxField label={t`Thursday`} value={'thursday'} checked={on.includes('thursday')}/>
                <CheckboxField label={t`Friday`} value={'friday'} checked={on.includes('friday')}/>
                <CheckboxField label={t`Saturday`} value={'saturday'} checked={on.includes('saturday')}/>
            </FormGroup>
        </FormControl>
    );
});