import * as React from 'react';
import {TabPanel, TabPanelProps} from "../component_permissions/TabPanel";
import { observer } from 'mobx-react-lite';
import {ButtonField} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {Transport} from "@rx-suite/data";

type Props = TabPanelProps;

type BtnProps = {
    text: string;
    url: string;
}

const Btn: React.FunctionComponent<BtnProps> = ({ text, url }) => {
    const [invalidating, setInvalidating] = React.useState(false);
    const handleClick = React.useCallback(async () => {
        setInvalidating(true);
        await Transport.fetch(url, {
            method: "POST",
            headers: {
                'Content-Type': 'application/json'
            }
        })
        setInvalidating(false);
    }, [url]);

    return(
        <ButtonField text={text} onClick={handleClick} loading={invalidating} />
    )
}

export const MaintenanceActionsTab: React.FunctionComponent<Props> = observer(({ value, index }) => {
    return(
        <TabPanel value={value} index={index}>
            <Btn text={t`Invalidate User Cache`} url={"/api/maintenance/invalidate_user_cache"} />
            <Btn text={t`Invalidate Endpoint Cache`} url={"/api/maintenance/invalidate_endpoint_cache"} />
        </TabPanel>
     )
});