import * as React from 'react';
import {observer} from "mobx-react-lite";
import {ButtonField, ModelForm, ModelInput, TitleSetter} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {RxModulePackageModel} from "../../stores/RxModulePackageStore";
import {RxModuleComponentStore} from "../../stores/RxModuleComponentStore";
import {makeStyles} from "@material-ui/core/styles";
import {Model, routerStore} from "@rx-suite/data";

const useStyles = makeStyles({
    port: {
        display: "flex",
        width: '100%'
    },
    portInput: {
        flexGrow: 1
    }
});

export const AppInstallForm: React.FunctionComponent<{ model: Model }> = observer(({model}) => {
    const classes = useStyles();
    React.useEffect(() => {
        (model as RxModulePackageModel).findPort()
    }, [model, model.id])
    return <>
        <TitleSetter title={`${t`Configure Installation`}: ${model.getId()}`}/>
        <ModelForm model={model} submitText={t`Start Installation`} suppressImportExport suppressRedirect
                   afterSubmit={(_, resp) => {
                       model.store.refreshData();
                       const readLink = RxModuleComponentStore.readLink(resp.id);
                       if (readLink) {
                           routerStore.history.push(readLink);
                       }
                   }}>
            <div className={classes.port}><ModelInput name={"port"} className={classes.portInput}/>
                <ButtonField text={t`Find Unallocated`} onClick={(model as RxModulePackageModel).findPort}/>
            </div>
        </ModelForm>
    </>

});